import setuptools

setuptools.setup(
    name="xesoython",
    version="0.0.2",
    author="Chengze Li",
    author_email="3161399620@qq.com",
    description="xesoython 本库作者:李承泽 (若正常路线下载失败，请切换python原版路线！)",
    long_description_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)